Skip to contents

Coefficients for a JAGS analysis.

Usage

# S3 method for class 'mb_analysis'
coef(
  object,
  param_type = "fixed",
  include_constant = TRUE,
  conf_level = getOption("mb.conf_level", 0.95),
  estimate = getOption("mb.estimate", median),
  simplify = TRUE,
  directional_information = FALSE,
  ...
)

Arguments

object

The mb_analysis object.

param_type

A flag specifying whether 'fixed', 'random' or 'derived' terms.

include_constant

A flag specifying whether to include constant terms.

conf_level

A number specifying the confidence level. By default 0.95.

estimate

The function to use to calculating the estimate for Bayesian models.

simplify

Must be TRUE. simplify = FALSE is defunct as of embr 1.1.0.

directional_information

A flag specifying whether the svalue column for a Bayesian analysis should be calculated using extras::directional_information() instead of extras::svalue(). The default value will change from FALSE to TRUE in a future release; set the argument explicitly to avoid the deprecation warning. Ignored for frequentist analyses where the svalue is always -log2(pvalue).

...

Not used.

Value

A tidy tibble of the coefficient terms with the columns indicating the term, estimate, lower and upper confidence or credible intervals and svalue.