Computes power-scaling sensitivity and stores the result as x$sensitivity.
Subsequent calls return x unchanged unless replace = TRUE.
Arguments
- x
The object.
- new_expr
A string of R code specifying the predictive relationship. Must use
replace = TRUEfor this to be applied.- replace
A flag specifying whether to replace an existing sensitivity data frame.
- ...
Arguments passed to
powerscale_sensitivity().