Coefficients for a JAGS analysis.
Arguments
- object
The mb_analysis object.
- param_type
A flag specifying whether 'fixed', 'random' or 'derived' terms.
- include_constant
A flag specifying whether to include constant terms.
- conf_level
A number specifying the confidence level. By default 0.95.
- estimate
The function to use to calculating the estimate for Bayesian models.
- simplify
Must be
TRUE.simplify = FALSEis defunct as of embr 1.1.0.- directional_information
A flag specifying whether the svalue column for a Bayesian analysis should be calculated using
extras::directional_information()instead ofextras::svalue(). The default value will change fromFALSEtoTRUEin a future release; set the argument explicitly to avoid the deprecation warning. Ignored for frequentist analyses where the svalue is always-log2(pvalue).- ...
Not used.